******************************
The sherpa.models.model module
******************************

.. currentmodule:: sherpa.models.model

.. automodule:: sherpa.models.model

   .. rubric:: Classes
               
   .. autosummary::
      :toctree: api

      Model
      ArithmeticConstantModel
      ArithmeticFunctionModel
      ArithmeticModel
      CompositeModel
      BinaryOpModel
      FilterModel
      MultigridSumModel
      NestedModel
      RegriddableModel1D
      RegriddableModel2D
      SimulFitModel
      UnaryOpModel
   
Class Inheritance Diagram
=========================

.. inheritance-diagram:: Model ArithmeticConstantModel ArithmeticFunctionModel ArithmeticModel CompositeModel BinaryOpModel FilterModel MultigridSumModel NestedModel RegriddableModel1D RegriddableModel2D SimulFitModel UnaryOpModel
   :parts: 1
   
